<?php
chdir(dirname(__FILE__)); //Pour le lancement en cron

require_once "OmbutelLink.php";
require_once '../classes/Contact.php';

//récupération du token
$token = GetToken();
if ($token === FALSE)
{
    echo "Echec identification API";
    exit(-1);
}

$extensions = GetExtensions($token);
if ($extensions === FALSE)
{
    echo "Echec récupération extensions";
    exit(-1);
}
$cpbxcontacts = GetContacts($token);
if ($cpbxcontacts === FALSE)
{
    echo "Echec récupération contacts";
    $cpbxcontacts = [];
}

//Récupération de tous les contacts internes pour comparaison
$contacts = Contact::GetContacts(OUCOMMUN, "interne_*");
echo "L'annuaire comporte actuellement " . count($contacts) . " contacts" . PHP_EOL;
echo "Il y a " . count($extensions) . " extensions sur l'IPBX." . PHP_EOL;
echo "---" . PHP_EOL;

//En premier, on parcours nos contacts internes. Si un contact n'existe plus, on le supprime
echo "ETAPE 1 : Suppression des contacts suppimés" . PHP_EOL;
$nbsuppr = 0;
foreach ($contacts as $c)
{
    if ($c->interne)
    {
        $existe = false;
        foreach ($extensions as $ext)
        {
            //on reconstruit l'ID de l'extension
            $id = "interne_" . $ext->extension;
            if ($id === $c->id)
            {
                $existe = true;
            }
        }
        if (!$existe)
        {
            echo "Suppression du contact " . $c->id . PHP_EOL;
            $c->Delete();
            $$nbsuppr++;
        }
    }
}
echo $nbsuppr . " contacts supprimés" . PHP_EOL;
echo "---" . PHP_EOL;
echo "ETAPE 2 : Recherche des nouveaux contacts et contacts modifies." . PHP_EOL;
$nbadd = 0;
$nbmod = 0;
foreach ($extensions as $ext)
{
    $cpbxcontact = null;
    //recherche le contact CPBX
    foreach ($cpbxcontacts as $cpbxc) {
        if ($ext->extension_id === $cpbxc->extension_id) {
            $cpbxcontact = $cpbxc;
        }
    }
    
    $societe = "";
    $numero = "";
    $nom = "";
    $email = "";
    $sda = "";
    $fonction = "";
    
    if ($ext->extension !== null)
        $numero = $ext->extension;
    if ($ext->name !== null)
        $prenom = $ext->name;
    if ($ext->email !== null)
        $email = $ext->email;
    if ($ext->did_number !== null)
        $sda = $ext->did_number;
    if ($ext->did_number !== null)
        $sda = $ext->did_number;
    
    if ($cpbxcontact !== null) {
        if ($cpbxcontact->organization !== null)
            $societe = $cpbxcontact->organization;
        if ($cpbxcontact->department !== null)
            $fonction = $cpbxcontact->department;
    }
    
    //Construction d'un ID de contact sous la forme: interne_extension
    $id = "interne_" . $numero;
    
    //on recherche le contact parmis les contacts existants. si le contact n'existe pas on le créé, sinon on regarde si on doit le modifier
    $cont = null;
    foreach ($contacts as $c)
    {
        if ($c->id === $id)
        {
            $cont = $c;
        }
    }
    
    if ($cont === null)
    {
        //Création du contact
        echo "Ajout extension " . $numero . " - Prenom : " . $prenom . " - Email : " . $email . " - SDA : " . $sda . PHP_EOL;
        $c = new Contact($id, $societe, "", $prenom, $numero, "", $sda, $email, $fonction, OUCOMMUN);
        $c->interne = true;
        $c->nouveau = true;
        $c->Save();
        $nbadd++;
    }
    else
    {
        //doit on modifier ?
        if ($cont->societe !== $societe
                || $cont->fonction !== $fonction
                || $cont->prenom !== $prenom
                || $cont->email !== $email
                || $cont->telephone !== $numero
                || $cont->autre !== $sda)
        {
            //Modification du contact
            echo "Modification extension " . $numero . " - Prenom : " . $prenom . " - Email : " . $email . " - SDA : " . $sda . PHP_EOL;
            $c = new Contact($id, $societe, "", $prenom, $numero, "", $sda, $email, $fonction, OUCOMMUN);
            $c->interne = true;
            $c->nouveau = false;
            $c->Save();
            $nbmod++;
        }
    }  
}
echo $nbadd . " contacts ajoutés" . PHP_EOL;
echo $nbmod . " contacts modifies" . PHP_EOL;
echo "---" . PHP_EOL;
echo "FIN DU SCRIPT" . PHP_EOL . PHP_EOL;